SurahVerses class abstract

Implementers

Constructors

SurahVerses({required int surahNumber, required int startVerseNumber, required int endVerseNumber, required Map<int, Verse> verses, required int verseCount})
Constructor for creating a SurahVerses object.

Properties

endVerseNumber int
The verse number at which the Surah ends in the Juz.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startVerseNumber int
The verse number at which the Surah starts in the Juz.
final
surahNumber int
The number of the Surah.
final
verseCount int
The total number of verses in the Surah.
final
verses Map<int, Verse>
A map containing the verses of the Surah, where the key is the verse number and the value is the Verse object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited