Quran class

The Quran class provides methods to access Quranic data and translations.

Constructors

Quran()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getJuzAsList() List<Juz>
Retrieves the list of all juz.
getJuzAsMap() Map<int, Juz>
Retrieves the map of all juz.
getJuzNumber({required int surahNumber, required int verseNumber}) int
Retrieves the juz number that contains the specified surah and verse.
getPageAsList() List<QuranPage>
Retrieves the list of all pages.
getPageAsMap() Map<int, QuranPage>
Retrieves the map of all pages.
getPageNumber({required int surahNumber, required int verseNumber}) int
Retrieves the juz number that contains the specified surah and verse.
getQuranVerses({QuranLanguage? language}) Map<int, Map<int, Verse>>
Retrieves the Quranic verses in the specified language.
getRevealationOrderInSurah(int surahNumber) int
Retrieves the revelation order of a surah.
getRukusInSurah(int surahNumber) int
Retrieves the number of rukus in a surah.
getSurah(int surahNumber) Surah
Retrieves a Surah object by its number.
getSurahAsList() List<Surah>
Retrieves the list of all surahs.
getSurahAsMap() Map<int, Surah>
Retrieves the map of all surahs.
getSurahName(int surahNumber) String
Retrieves the name of a surah by its number.
getSurahNameEnglish(int surahNumber) String
Retrieves the English name of a surah by its number.
getSurahType(int surahNumber) SurahType
Retrieves the type of a surah (Makki or Madani).
getSurahVersesAsList(int surahNumber, {QuranLanguage? language}) List<Verse>
Retrieves all the verses of a surah as a list.
getSurahVersesAsMap(int surahNumber, {QuranLanguage? language}) Map<int, Verse>
Retrieves all the verses of a surah as a map.
getSurahVersesInJuzAsList(int juzNumber) List<JuzSurahVerses>
Retrieves the surah verses in a juz as a list.
getSurahVersesInJuzAsMap(int juzNumber) Map<int, JuzSurahVerses>
Retrieves the surah verses in a juz as a map.
getSurahVersesInPageAsList(int pageNumber) List<PageSurahVerses>
Retrieves the surah verses in a page as a list.
getSurahVersesInPageAsMap(int pageNumber) Map<int, PageSurahVerses>
Retrieves the surah verses in a page as a map.
getTotalVersesInJuz(int juzNumber) int
Retrieves the total number of verses in a juz.
getTotalVersesInPage(int pageNumber) int
Retrieves the total number of verses in a page.
getTotalVersesInSurah(int surahNumber) int
Retrieves the total number of verses in a surah.
getTotalVersesOfSurahInJuz({required int surahNumber, required int juzNumber}) int
Retrieves the total number of verses of a surah in a specific juz.
getTotalVersesOfSurahInPage({required int surahNumber, required int pageNumber}) int
Retrieves the total number of verses of a surah in a specific page.
getVerse({required int surahNumber, required int verseNumber, QuranLanguage? language}) Verse
Retrieves a Verse object by its surah and verse numbers.
initialize() Future<void>
Initializes the Quranic data and translations.
isMadaniSurah(int surahNumber) bool
Returns true if the surah is a Madani surah.
isMakkiSurah(int surahNumber) bool
Returns true if the surah is a Makki surah.

Constants

bismillah → const String
The Bismillah phrase.
juzCount → const int
Total number of juz in the Quran.
madaniSurahCount → const int
Total number of Madani surahs in the Quran.
makkiSurahCount → const int
Total number of Makki surahs in the Quran.
pageCount → const int
Total number of pages in the Quran.
surahCount → const int
Total number of surahs in the Quran.
verseCount → const int
Total number of verses in the Quran.